@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: uuid
 version: 1.3.11
-id: uuid-1.3.11-95935b0432cec422536cd2e31dafa5cb
-key: uuid_930MG7FU4Nb13YdLyqXYHj
+id: uuid-1.3.11-88963c9f5cc3f56cbc943d5b6ea5ce69
+key: uuid_ATe83ABgxRjHt0P8K8eFNr
 license: BSD3
 copyright: (c) 2008-2014 Antoine Latter
 maintainer: aslatter@gmail.com
@@ -24,17 +24,17 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/uuid-1.3.11
 library-dirs: /usr/lib/ghc-7.10.3/site-local/uuid-1.3.11
 data-dir: /usr/share/arm-linux-ghc-7.10.3/uuid-1.3.11
-hs-libraries: HSuuid-1.3.11-930MG7FU4Nb13YdLyqXYHj
+hs-libraries: HSuuid-1.3.11-ATe83ABgxRjHt0P8K8eFNr
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    cryptohash-0.11.7-d9e0f8e58e69d0717d29fde3802983d0
+    cryptohash-0.11.9-66ecf9651f97183101697edd4149971c
     network-info-0.2.0.8-bc6c8aa48b93ac2c06aa2e5c4fa39eb6
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
-    uuid-types-1.0.2-e80dd8ed3b7ffef1dd40876281d96804
+    uuid-types-1.0.2-31d0afe3e94388f95aaba92ed882146a
 haddock-interfaces: /usr/share/doc/haskell-uuid/html/uuid.haddock
 haddock-html: /usr/share/doc/haskell-uuid/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
